[−][src]Function parse_hyperlinks::parser::restructured_text::rst_link
pub fn rst_link(i: &str) -> IResult<&str, (String, String)>
Parse a RestructuredText hyperlink.
This parse must start at the link start \`` to succeed. A hyperlink reference may directly embed a target URI or (since Docutils 0.11) a hyperlink reference within angle brackets ("<...>") as follows: See the Python home page http://www.python.org`_ for info.
The bracketed URI must be preceded by whitespace and be the last text
before the end string.
reStructuredText Markup
Specification