[][src]Enum parse_hyperlinks::parser::Link

pub enum Link<'a> {
    Text2Dest(Cow<'a, str>, Cow<'a, str>, Cow<'a, str>),
    Text2Label(Cow<'a, str>, Cow<'a, str>),
    Label2Dest(Cow<'a, str>, Cow<'a, str>, Cow<'a, str>),
    Label2Label(Cow<'a, str>, Cow<'a, str>),
}

A link can be an inline link, a reference link or a link reference definition. This is the main return type of this API.

Variants

Text2Dest(Cow<'a, str>, Cow<'a, str>, Cow<'a, str>)

In (stand alone) inline links the destination and title are given immediately after the link text. When the inline link is rendered, only the link_text is visible in the continuos text.

The tuple definition: Text2Dest(link_text, link_destination, link_title)

Text2Label(Cow<'a, str>, Cow<'a, str>)

In reference links the destination and title are defined elsewhere in the document in some link reference definition. When a reference link is rendered only the link_text is visible in the continuos text.

Tuple definition: Text2Label(link_text, link_label)

Label2Dest(Cow<'a, str>, Cow<'a, str>, Cow<'a, str>)

A link reference definition refers to a reference link with the same link label. A link reference definition is not visible when the document is rendered.

Tuple definition: Label2Dest(link_label, link_destination, link_title)

Label2Label(Cow<'a, str>, Cow<'a, str>)

The reference alias defines an alternative link label alt_link_label for an existing link_label defined elsewhere in the document. At some point the link_label needs to be resolved to a link_destination by some link_reference_definition. A reference alias is not visible when the document is rendered.

Tuple definition: Label2Label(alt_link_label, link_label)