[−][src]Module parse_hyperlinks::parser::restructured_text
This module implements parsers for RestructuredText hyperlinks.
Functions
| rst_link | Parse a RestructuredText hyperlink. The parser expects to start at the link start (`) to succeed. A hyperlink reference may directly embed a target URI or (since Docutils 0.11) a hyperlink reference within angle brackets ("<...>") as in |
| rst_link_ref | Parse a RestructuredText link references. The parser expects to start at the beginning of the line. Here some examples for link references: |