[][src]Module parse_hyperlinks::parser::restructured_text

This module implements parsers for RestructuredText hyperlinks.

Functions

rst_link

Parse a RestructuredText hyperlink. This parse must start at the link start \`` to succeed. A hyperlink reference may directly embed a target URI or (since Docutils 0.11) a hyperlink reference within angle brackets ("<...>") as follows: See the Python home page http://www.python.org`_ for info. The bracketed URI must be preceded by whitespace and be the last text before the end string. reStructuredText Markup Specification

rst_link_ref

Parser and transform RestructuredText link references. The parser expects to start at the beginning of the line. Here some examples for link references: See the Python home page_ for info. .. _Python home page: http://www.python.org .. _Python: home page: http://www.python.org See unit test test_rst_link_ref()for more examples.