[−][src]Module parse_hyperlinks::parser::restructured_text
This module implements parsers for RestructuredText hyperlinks.
Functions
| rst_link | Parse a RestructuredText hyperlink.
This parse must start at the link start |
| rst_link_ref | Parser and transform RestructuredText link references.
The parser expects to start at the beginning of the line.
Here some examples for link references:
See the |